qmail-util
==========


![Image](https://img.shields.io/github/license/rstms/qmail_util)

![Image](https://img.shields.io/pypi/v/qmail_util.svg)



![Image](https://readthedocs.org/projects/qmail-util/badge/?version=latest)

![Image](https://pyup.io/repos/github/rstms/qmail_util/shield.svg)

Qmail mailserver maintenance tool


* Free software: MIT license
* Documentation: https://qmail-util.readthedocs.io.



Credits
-------

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
